/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import junit.framework.TestCase;
import org.apache.tools.ant.BuildException;

import java.util.HashMap;
import java.util.Map;


/**
 * This class contains the unit tests for {@link CredentialProperty}.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class CredentialPropertyTest extends TestCase {
    /**
     * This is a name used in test cases.
     */
    private static final String NAME = "XXName";
    /**
     * This is a value used in test cases.
     */
    private static final String VALUE = "value";
    /**
     * This is a map used in test cases, initialized in {@link #setUp()}.
     */
    private Map map;
    /**
     * This is the instance to be tested, initialized in {@link #setUp()}.
     */
    private CredentialProperty property;

    /**
     * This method tests {@link CredentialProperty#CredentialProperty(String, java.util.Map)} for correctness.
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtor() throws Exception {
        final CredentialProperty instance = new CredentialProperty(NAME, map);
        assertEquals(NAME, TestingUtils.getFieldValue(instance, "name"));
        assertEquals(map, TestingUtils.getFieldValue(instance, "propertyMap"));
    }

    /**
     * This method tests the correct failure behavior of {@link CredentialProperty#CredentialProperty(String,
     * java.util.Map)}.
     * <p/>
     * <b>Failure reason</b>: <tt>null</tt> name given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailNullName() throws Exception {
        try {
            new CredentialProperty(null, map);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link CredentialProperty#CredentialProperty(String,
     * java.util.Map)}.
     * <p/>
     * <b>Failure reason</b>: empty name given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailEmptyName() throws Exception {
        try {
            new CredentialProperty("  ", map);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link CredentialProperty#CredentialProperty(String,
     * java.util.Map)}.
     * <p/>
     * <b>Failure reason</b>: <tt>null</tt> propertyMap given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailNullPropertyMap() throws Exception {
        try {
            new CredentialProperty(NAME, null);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests {@link CredentialProperty#setValue(String)} for correctness.
     */
    public void testGetProject() {
        assertEquals(0, map.size());
        property.setValue(VALUE);
        assertEquals(VALUE, map.get(NAME));
    }

    /**
     * This method tests the correct failure behavior of {@link CredentialProperty#setValue(String)}.
     * <p/>
     * <b>Failure reason</b>: duplicate property name in property map
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testSetValueFailDuplicatePropertyName() throws Exception {
        map.put(NAME, VALUE);
        try {
            property.setValue(VALUE);
            fail("should throw");
        } catch (BuildException expected) {
            //expected
        }
    }

    /**
     * This method does the test setup needed.
     *
     * @throws Exception in case some unexpected Exception occurs
     */
    protected void setUp() throws Exception {
        super.setUp();
        map = new HashMap();
        property = new CredentialProperty(NAME, map);
    }
}
