/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

/**
 * This is a mock class used in test cases. Its purpose is to have class that is of type {@link Server} which has no
 * accessible constructor with a single String signature.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class DummyServerWrongConstructor extends Server {
    /**
     * This is the constructor which does not have the signature expected by {@link
     * ServerElement#createDynamicElement(String)}, which expects a single String constructor. Thus this class is not
     * instantiatable by {@link ServerElement#createDynamicElement(String)}.
     *
     * @param type      one arg
     * @param secondArg second arg
     */
    public DummyServerWrongConstructor(final String type, final String secondArg) {
        super(type);
    }

    /**
     * This method starts the server. In the case when <tt>startserver</tt> attribute is set to <tt>false</tt>, the
     * server should not be started, but some initialization may still be needed. Subclasses must implement this method
     * to perform the actual task of starting up the server.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void startUp() {

    }

    /**
     * This method stops the server. The server should not be stopped if it wasn't started by the startUp() method, i.e.
     * <tt>startserver</tt> attribute is set to <tt>false</tt>. Subclasses must implement this method to perform the
     * actual task of stopping the server.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void shutDown() {

    }

    /**
     * This method initializes the server  with data. In the case when <tt>initserver</tt> attribute is set to
     * <tt>false</tt>, does nothing, or can check if the data are properly initialized, the implementation can choose
     * the preferred way. Subclasses must implement this method to perform the actual task of initializing server with
     * data.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void initData() {

    }

    /**
     * This method cleans up the data initialized by the {@link #initData()} method. In the case when
     * <tt>initserver</tt> attribute is set to <tt>false</tt> or data was not initialized, does nothing. Subclasses must
     * implement this method to perform the actual task of  cleaning-up the data.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void cleanUpData() {

    }
}
