/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package demo;

import com.topcoder.testframework.web.TCServletTestCase;
import org.apache.cactus.WebRequest;
import org.apache.cactus.WebResponse;


/**
 * This class is an usage example on how the Testing framework component is used in writing In-Container test cases for
 * J2EE components.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class DemoTestCase extends TCServletTestCase {
    /**
     * This method is called on the client side before {@link #testSaveToSessionOK()} is invoked on the Server. The
     * WebRequest instance supplied can be used to set request parameters to the HTTP request.
     *
     * @param webRequest the request instance that will be sent to server and will be used as request (i.e. as return
     *                   value of {@link #getRequest()}) instance when {@link #testSaveToSessionOK()} is called on the
     *                   server
     */
    public void beginSaveToSessionOK(final WebRequest webRequest) {
        webRequest.addParameter("testparam", "it works!");
    }

    /**
     * This method performs the actual testing. It is called by the testing framework on server after the context has
     * been initialized (i.e. {@link #getRequest()}, {@link #getResponse()}, {@link #getSession()} etc. return valid
     * values).
     */
    public void testSaveToSessionOK() {
        final DemoServlet servlet = new DemoServlet();
        servlet.saveToSession(getRequest(), getResponse());
        assertEquals("attribute not written to session", "it works!", getSession().getAttribute("testAttribute"));
    }

    /**
     * This method is called on the client side after completion of {@link #testSaveToSessionOK()}  on server side, with
     * the parsed version of the response sent on server during the test.
     *
     * @param response the parsed version of the response received from {@link #testSaveToSessionOK()}
     */
    public void endSaveToSessionOK(final WebResponse response) {
        assertEquals("response cookie not set", "true", response.getCookie("initialized").getValue());
    }
}
